@@ -33,59 +33,51 @@ Example:
     - This module will only run on Core (client) platforms.
 """
 
-from chipsec.module_common import BaseModule, ModuleResult, MTAG_HWCONFIG
+from chipsec.module_common import BaseModule, HWCONFIG
+from chipsec.library.returncode import ModuleResult
+from typing import List
 
 _MODULE_NAME = 'memconfig'
 
-TAGS = [MTAG_HWCONFIG]
-
-
-memmap_registers = {
-    "PCI0.0.0_GGC": 'GGCLOCK',
-    "PCI0.0.0_PAVPC": 'PAVPLCK',
-    "PCI0.0.0_DPR": 'LOCK',
-    "PCI0.0.0_MESEG_MASK": 'MELCK',
-    "PCI0.0.0_REMAPBASE": 'LOCK',
-    "PCI0.0.0_REMAPLIMIT": 'LOCK',
-    "PCI0.0.0_TOM": 'LOCK',
-    "PCI0.0.0_TOUUD": 'LOCK',
-    "PCI0.0.0_BDSM": 'LOCK',
-    "PCI0.0.0_BGSM": 'LOCK',
-    "PCI0.0.0_TSEGMB": 'LOCK',
-    "PCI0.0.0_TOLUD": 'LOCK'
-}
-
-memmap_registers_dev0bars = [
-    "PCI0.0.0_PXPEPBAR",
-    "PCI0.0.0_MCHBAR",
-    "PCI0.0.0_PCIEXBAR",
-    "PCI0.0.0_DMIBAR",
-]
+TAGS = [HWCONFIG]
+METADATA_TAGS = ['OPENSOURCE', 'IA', 'COMMON', 'MEMCONFIG']
 
 
 class memconfig(BaseModule):
 
     def __init__(self):
         BaseModule.__init__(self)
+        self.memmap_registers = {
+            'PCI0.0.0_GGC': 'GGCLOCK',
+            'PCI0.0.0_PAVPC': 'PAVPLCK',
+            'PCI0.0.0_DPR': 'LOCK',
+            'PCI0.0.0_MESEG_MASK': 'MELCK',
+            'PCI0.0.0_REMAPBASE': 'LOCK',
+            'PCI0.0.0_REMAPLIMIT': 'LOCK',
+            'PCI0.0.0_TOM': 'LOCK',
+            'PCI0.0.0_TOUUD': 'LOCK',
+            'PCI0.0.0_BDSM': 'LOCK',
+            'PCI0.0.0_BGSM': 'LOCK',
+            'PCI0.0.0_TSEGMB': 'LOCK',
+            'PCI0.0.0_TOLUD': 'LOCK'
+        }
 
-    def is_supported(self):
+    def is_supported(self) -> bool:
         if self.cs.is_intel():
             if self.cs.is_core():
                 return True
             self.logger.log_important("Not a 'Core' (Desktop) platform.  Skipping test.")
         else:
-            self.logger.log_important("Not an Intel platform.  Skipping test.")
-        self.res = ModuleResult.NOTAPPLICABLE
+            self.logger.log_important('Not an Intel platform.  Skipping test.')
         return False
 
-    def check_memmap_locks(self):
+    def check_memmap_locks(self) -> int:
 
-        # Determine if IA_UNTRUSTED can be used to lock the system.
         ia_untrusted = None
-        if self.cs.register_has_field('MSR_BIOS_DONE', 'IA_UNTRUSTED'):
-            ia_untrusted = self.cs.read_register_field('MSR_BIOS_DONE', 'IA_UNTRUSTED')
+        if self.cs.register.has_field('MSR_BIOS_DONE', 'IA_UNTRUSTED'):
+            ia_untrusted = self.cs.register.read_field('MSR_BIOS_DONE', 'IA_UNTRUSTED')
 
-        regs = sorted(memmap_registers.keys())
+        regs = sorted(self.memmap_registers.keys())
         all_locked = True
 
         self.logger.log('[*]')
@@ -94,19 +86,19 @@ class memconfig(BaseModule):
         else:
             self.logger.log('[*] Checking register lock state:')
         for reg in regs:
-            reg_field = memmap_registers[reg]
-            if not self.cs.register_has_field(reg, reg_field):
+            reg_field = self.memmap_registers[reg]
+            if not self.cs.register.has_field(reg, reg_field):
                 self.logger.log_important(f'Skipping Validation: Register {reg} or field {reg_field} was not defined for this platform.')
                 continue
-            reg_def = self.cs.get_register_def(reg)
-            reg_value = self.cs.read_register(reg)
+            reg_def = self.cs.register.get_def(reg)
+            reg_value = self.cs.register.read(reg)
             reg_desc = reg_def['desc']
-            locked = self.cs.get_register_field(reg, reg_value, reg_field)
+            locked = self.cs.register.get_field(reg, reg_value, reg_field)
             if locked == 1:
-                self.logger.log_good(f"{reg:20} = 0x{reg_value:016X} - LOCKED   - {reg_desc}")
+                self.logger.log_good(f'{reg:20} = 0x{reg_value:016X} - LOCKED   - {reg_desc}')
             else:
                 all_locked = False
-                self.logger.log_bad(f"{reg:20} = 0x{reg_value:016X} - UNLOCKED - {reg_desc}")
+                self.logger.log_bad(f'{reg:20} = 0x{reg_value:016X} - UNLOCKED - {reg_desc}')
 
         if ia_untrusted is not None:
             self.logger.log('[*]')
@@ -120,15 +112,15 @@ class memconfig(BaseModule):
         self.logger.log('[*]')
         if all_locked:
             res = ModuleResult.PASSED
-            self.logger.log_passed("All memory map registers seem to be locked down")
+            self.logger.log_passed('All memory map registers seem to be locked down')
         else:
             res = ModuleResult.FAILED
-            self.logger.log_failed("Not all memory map registers are locked down")
+            self.logger.log_failed('Not all memory map registers are locked down')
+            self.result.setStatusBit(self.result.status.LOCKS)
 
         return res
 
-    def run(self, module_argv):
-        self.logger.start_test("Host Bridge Memory Map Locks")
-
+    def run(self, module_argv: List[str]) -> int:
+        self.logger.start_test('Host Bridge Memory Map Locks')
         self.res = self.check_memmap_locks()
-        return self.res
+        return self.result.getReturnCode(self.res)
