@@ -23,17 +23,12 @@
 Hyper-V specific hypercall functionality
 """
 
-import os
-import sys
-import time
-import binascii
-import chipsec_util
 from random import *
 from struct import *
 from chipsec.modules.tools.vmm.hv.define import *
 from chipsec.modules.tools.vmm.common import *
-from chipsec.logger import *
-from chipsec.file import *
+from chipsec.library.logger import *
+from chipsec.library.file import *
 from chipsec.module_common import *
 from chipsec.hal.vmm import *
 
@@ -55,20 +50,20 @@ class HyperVHypercall(BaseModuleHwAccess):
     def print_hypervisor_info(self):
         gprs = self.cpuid_info(0x00000001, 0x0, 'Feature Information')
         self.hypervisor_present = ((gprs[2] >> 31) & 0x1) == 0x1
-        self.msg('ECX(31) - Hypervisor Present                  :  {:x}'  .format(self.hypervisor_present))
+        self.msg(f'ECX(31) - Hypervisor Present                  :  {self.hypervisor_present:x}')
 
         if self.hypervisor_present:
 
             gprs = self.cpuid_info(0x40000000, 0x0, 'Hypervisor CPUID leaf range and vendor ID signature')
             (max_input_value, id_signature_ebx, id_signature_ecx, id_signature_edx) = gprs
             id_signature = pack('<3L', id_signature_ebx, id_signature_ecx, id_signature_edx)
-            self.msg('The maximum input value for hypervisor CPUID  :  {:08X}'.format(max_input_value))
-            self.msg('Hypervisor Vendor ID Signature                :  {}'.format(id_signature))
+            self.msg(f'The maximum input value for hypervisor CPUID  :  {max_input_value:08X}')
+            self.msg(f'Hypervisor Vendor ID Signature                :  {id_signature}')
 
             gprs = self.cpuid_info(0x40000001, 0x0, 'Hypervisor vendor-neutral interface identification')
             (interface_signature, rsvd_ebx, rsvd_ecx, rsvd_edx) = gprs
             interface_signature = pack('<1L', interface_signature)
-            self.msg('Hypervisor Interface Signature                :  {}'.format(interface_signature))
+            self.msg(f'Hypervisor Interface Signature                :  {interface_signature}')
 
             if interface_signature == 'Hv#1':
                 self.msg('INFO: HV hypervisor CPUID interface detected!')
@@ -91,35 +86,35 @@ class HyperVHypercall(BaseModuleHwAccess):
             minor_version = 0xFFFF & ebx
             service_branch = 0xFF & (edx >> 24)
             service_number = 0xFFFFFF & edx
-            self.msg('   EAX        - Build Number    :  {:08X}'  .format(eax))
-            self.msg('   EBX(31-16) - Major Version   :  {:04X}'  .format(major_version))
-            self.msg('   EBX(15-0)  - Minor Version   :  {:04X}'  .format(minor_version))
-            self.msg('   ECX        - Service Pack    :  {:08X}'  .format(ecx))
-            self.msg('   EDX(31-24) - Service Branch  :  {:02X}'  .format(service_branch))
-            self.msg('   EDX(23-0)  - Service Number  :  {:06x}'  .format(service_number))
+            self.msg(f'   EAX        - Build Number    :  {eax:08X}')
+            self.msg(f'   EBX(31-16) - Major Version   :  {major_version:04X}')
+            self.msg(f'   EBX(15-0)  - Minor Version   :  {minor_version:04X}')
+            self.msg(f'   ECX        - Service Pack    :  {ecx:08X}')
+            self.msg(f'   EDX(31-24) - Service Branch  :  {service_branch:02X}')
+            self.msg(f'   EDX(23-0)  - Service Number  :  {service_number:06x}')
         elif cpuid_eax == 0x40000003:
             (eax, ebx, ecx, edx) = self.cpuid_info(cpuid_eax, cpuid_ecx, 'Feature identification')
-            self.msg('   EAX - features available to the partition                :  {:08X}'.format(eax))
+            self.msg(f'   EAX - features available to the partition                :  {eax:08X}')
             self.info_bitwise(eax, cpuid_desc[cpuid_eax]['EAX'])
-            self.msg('   EBX - flags specified at partition creation              :  {:08X}'.format(ebx))
+            self.msg(f'   EBX - flags specified at partition creation              :  {ebx:08X}')
             self.info_bitwise(ebx, cpuid_desc[cpuid_eax]['EBX'])
-            self.msg('   ECX - power management related information               :  {:08X}'.format(ecx))
+            self.msg(f'   ECX - power management related information               :  {ecx:08X}')
             self.info_bitwise(ecx, cpuid_desc[cpuid_eax]['ECX'])
-            self.msg('   EDX - misc. features available to the partition          :  {:08X}'.format(edx))
+            self.msg(f'   EDX - misc. features available to the partition          :  {edx:08X}')
             self.info_bitwise(edx, cpuid_desc[cpuid_eax]['EDX'])
         elif cpuid_eax == 0x40000004:
             (eax, ebx, ecx, edx) = self.cpuid_info(cpuid_eax, cpuid_ecx, 'Implementation recommendations')
-            self.msg('   EAX(9-0) - recommendations for optimal performance       :  {:08X}'.format(eax))
-            self.msg('   EBX      - recommended number of attempts                :  {:08X}'.format(ebx))
+            self.msg(f'   EAX(9-0) - recommendations for optimal performance       :  {eax:08X}')
+            self.msg(f'   EBX      - recommended number of attempts                :  {ebx:08X}')
         elif cpuid_eax == 0x40000005:
             (eax, ebx, ecx, edx) = self.cpuid_info(cpuid_eax, cpuid_ecx, 'Implementation limits')
-            self.msg('   EAX - The maximum number of virtual processors supported :  {:08X}'.format(eax))
-            self.msg('   EBX - The maximum number of logical processors supported :  {:08X}'.format(ebx))
-            self.msg('   ECX - The maximum number of physical interrupt vectors   :  {:08X}'.format(ecx))
+            self.msg(f'   EAX - The maximum number of virtual processors supported :  {eax:08X}')
+            self.msg(f'   EBX - The maximum number of logical processors supported :  {ebx:08X}')
+            self.msg(f'   ECX - The maximum number of physical interrupt vectors   :  {ecx:08X}')
         elif cpuid_eax == 0x40000006:
             (eax, ebx, ecx, edx) = self.cpuid_info(cpuid_eax, cpuid_ecx, 'Implementation hardware features')
-            self.msg('   EAX - Intel-specific features  :  {:08X}'.format(eax))
-            self.msg('   EDX - AMD-specific features    :  {:08X}'.format(edx))
+            self.msg(f'   EAX - Intel-specific features  :  {eax:08X}')
+            self.msg(f'   EDX - AMD-specific features    :  {edx:08X}')
         else:
             (eax, ebx, ecx, edx) = self.cpuid_info(cpuid_eax, cpuid_ecx, '')
         return
@@ -134,10 +129,11 @@ class HyperVHypercall(BaseModuleHwAccess):
         for addr in sorted(msrs.keys()):
             name = get_msr_name(addr)
             try:
-                result = "0x{:08X}_{:08X}".format(*self.rdmsr(addr))
+                readValue = self.rdmsr(addr)
+                result = f'0x{readValue[0]:08X}_{readValue[1]:08X}'
             except Exception as e:
                 result = str(e)
-            self.msg('RDMSR [{:40} = 0x{:08X}] :  {}'.format(name, addr, result))
+            self.msg(f'RDMSR [{name:40} = 0x{addr:08X}] :  {result}')
         return
 
     ##
@@ -146,7 +142,7 @@ class HyperVHypercall(BaseModuleHwAccess):
     def scan_hypercalls(self, code_list):
         for call_code in code_list:
             data = self.get_initial_data(GOOD_PARAMS_STATUSES, call_code, 112)
-            self.dbg('PROBING HYPERCALL: 0x{:04X}'.format(call_code))
+            self.dbg(f'PROBING HYPERCALL: 0x{call_code:04X}')
             for buffer in data:
                 try:
                     self.dbg('- FAST HYPERCALL')
@@ -174,7 +170,7 @@ class HyperVHypercall(BaseModuleHwAccess):
                     if result != HV_STATUS_INVALID_HYPERCALL_CODE:
                         self.hv_hypercalls[call_code] = [hv_rep, hv_fast, result]
                 except Exception as e:
-                    self.msg('Exception on hypercall (0x{:08X}): {}'.format(call_code, str(e)))
+                    self.msg(f'Exception on hypercall (0x{call_code:08X}): {str(e)}')
         return
 
     ##
@@ -240,7 +236,7 @@ class HyperVHypercall(BaseModuleHwAccess):
             self.msg('*************** Status codes statistics: *****************')
             for n in sorted(statistics.keys()):
                 status = get_hypercall_status(n, 'Not defined')
-                self.msg('{:50}: {:d}'.format(status, statistics[n]))
+                self.msg(f'{status:50}: {statistics[n]:d}')
             self.hex('Input Parameters', pattern[:0x20])
         else:
             self.msg('')
@@ -280,11 +276,11 @@ class HyperVHypercall(BaseModuleHwAccess):
                     x = v + 1
                 if (matrix[l][v] in status_list) and (matrix[l][v + 1] not in status_list):
                     if (x == v):
-                        ranges.append('{:02X}'.format(x))
+                        ranges.append(f'{x:02X}')
                     else:
-                        ranges.append('{:02X}-{:02X}'.format(x, v))
+                        ranges.append(f'{x:02X}-{v:02X}')
             if (ranges != ['00-FF']) and (ranges != []):
-                self.msg('  Byte {:02d} = [ {} ]'.format(l, ', '.join(ranges)))
+                self.msg(f'  Byte {l:02d} = [{", ".join(ranges)}]')
         return
 
     ##
@@ -296,7 +292,7 @@ class HyperVHypercall(BaseModuleHwAccess):
         self.msg('Start input parameters fuzzing ...')
         for x in range(total_tests):
             if x % 10000000 == 10000000 - 1:
-                self.msg('{:4.0f}% DONE'.format(100.0 * x / total_tests))
+                self.msg(f'{100.0 * x / total_tests:4.0f}% DONE')
             l = randint(0, maxlen - 1)
             v = randint(0, 0x100 - 1)
             if matrix[l][v] == 1:
@@ -325,7 +321,7 @@ class HyperVHypercall(BaseModuleHwAccess):
             status = get_hypercall_status(hc[2])
             hcname = get_hypercall_name(i)
             if status not in status_list:
-                self.msg("HYPERV_HYPERCALL REP:{:d} FAST:{:d} {:04X}  {:02X}  {:40} '{}'".format(hc[0], hc[1], i, hc[2], status, hcname))
+                self.msg(f'HYPERV_HYPERCALL REP:{hc[0]:d} FAST:{hc[1]:d} {i:04X}  {hc[2]:02X}  {status:40} \'{hcname}\'')
         return
 
     ##
@@ -335,10 +331,10 @@ class HyperVHypercall(BaseModuleHwAccess):
         self.msg('')
         self.msg('*** Hypervisor Partition IDs ***')
         if len(self.hv_partitionid) == 0:
-            self.msg('  was not able to dertemine Partition IDs')
+            self.msg('  was not able to determine Partition IDs')
         else:
             for i in sorted(self.hv_partitionid.keys()):
-                self.msg('{:08X}'.format(i))
+                self.msg(f'{i:08X}')
         return
 
     ##
@@ -355,7 +351,7 @@ class HyperVHypercall(BaseModuleHwAccess):
                     buffer = pack('<QLL', partid, prop, 0)
                     result = self.hv.hypercall64_memory_based(hciv, buffer, 8)
                     if result == HV_STATUS_SUCCESS:
-                        self.msg('  Partition: {:08X}  Property: {:08X}  Value: {:016x}'.format(partid, prop, unpack('<Q', self.hv.output)[0]))
+                        self.msg(f'  Partition: {partid:08X}  Property: {prop:08X}  Value: {unpack("<Q", self.hv.output)[0]:016x}')
         return
 
     ##
@@ -365,8 +361,8 @@ class HyperVHypercall(BaseModuleHwAccess):
         hciv = hv_hciv(0, 0, HV_SET_PARTITION_PROPERTY)
         buffer = pack('<QLLQ', part, prop, 0, value)
         result = self.hv.hypercall64_memory_based(hciv, buffer)
-        status = get_hypercall_status(result, '0x{:08X}'.format(result))
-        self.msg('>>> Setting partition property:  Partition: {:08X}  Property: {:08X}  Value: {:016x}  Status: {}'.format(part, prop, value, status))
+        status = get_hypercall_status(result, f'0x{result:08X}')
+        self.msg(f'>>> Setting partition property:  Partition: {part:08X}  Property: {prop:08X}  Value: {value:016x}  Status: {status}')
         return
 
     ##
@@ -377,7 +373,7 @@ class HyperVHypercall(BaseModuleHwAccess):
         self.msg('*** Hypervisor Connection IDs ***')
         for i in sorted(self.hv_connectionid.keys()):
             connid = self.hv_connectionid[i]
-            self.msg('{:08X}  {:02X}  {}'.format(i, connid, hv_porttype[connid]))
+            self.msg(f'{i:08X}  {connid:02X}  {hv_porttype[connid]}')
         return
 
     ##
@@ -390,7 +386,7 @@ class HyperVHypercall(BaseModuleHwAccess):
 
         if hcname == 'HvConnectPort':
             return
-            self.msg('Hypercall: {} '.format(hcname))
+            self.msg(f'Hypercall: {hcname} ')
             hciv = hv_hciv(0, 0, call_code)
             for i in range(0x0, 0xFFFFF):
                 buffer = pack('<5Q', i & 0xF, (i >> 4) & 0xF, (i >> 8) & 0xF, (i >> 12) & 0xF, (i >> 16) & 0xF)
@@ -398,11 +394,11 @@ class HyperVHypercall(BaseModuleHwAccess):
                 statistics[result] = 1 if result not in statistics else statistics[result] + 1
 
         elif hcname == 'HvPostMessage':
-            self.msg('Hypercall: {} '.format(hcname))
+            self.msg(f'Hypercall: {hcname} ')
             hciv = hv_hciv(0, 0, call_code)
             for connid in sorted(self.hv_connectionid.keys()):
                 if self.hv_connectionid[connid] == HV_PORT_TYPE_MESSAGE:
-                    self.msg('Connection ID: : {:08X}'.format(connid))
+                    self.msg(f'Connection ID: : {connid:08X}')
                     for i in range(0x100, 0x1000):
                         messagetype = 0x7FFFFFFF & getrandbits(32)
                         payloadsize = randint(0, 240)
@@ -410,14 +406,14 @@ class HyperVHypercall(BaseModuleHwAccess):
                         buffer = pack('<4LQ', connid, 0, messagetype, payloadsize, message0)
                         result = hv.hypercall64_memory_based(hciv, buffer)
                         statistics[result] = 1 if result not in statistics else statistics[result] + 1
-                        self.dbg('HvPostMessage: {} {}'.format(get_hypercall_status(result), binascii.hexlify(buffer)))
+                        self.dbg(f'HvPostMessage: {get_hypercall_status(result)} {buffer.hex()}')
 
         elif hcname == 'HvSignalEvent':
-            self.msg('Hypercall: {} '.format(hcname))
+            self.msg(f'Hypercall: {hcname} ')
             hciv = hv_hciv(0, 0, call_code)
             for connid in sorted(self.hv_connectionid.keys()):
                 if self.hv_connectionid[connid] == HV_PORT_TYPE_EVENT:
-                    self.msg('Connection ID: {:08X}'.format(connid))
+                    self.msg(f'Connection ID: {connid:08X}')
                     for i in range(min(total_tests, 0xFFFF)):
                         buffer = pack('<LHH', connid, 0, i)
                         result = self.hv.hypercall64_memory_based(hciv, buffer)
@@ -426,6 +422,6 @@ class HyperVHypercall(BaseModuleHwAccess):
         if len(statistics) > 0:
             self.msg('*************** Status codes statistics: *****************')
             for i in sorted(statistics.keys()):
-                self.msg('{:50}: {:d}'.format(get_hypercall_status(i), statistics[i]))
+                self.msg(f'{get_hypercall_status(i):50}: {statistics[i]:d}')
 
         return
